==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/sagemaker/NotebookInstanceLifecycleConfigReference.java <==
package software.amazon.awscdk.interfaces.sagemaker;

/**
 * A reference to a NotebookInstanceLifecycleConfig resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.sagemaker.*;
 * NotebookInstanceLifecycleConfigReference notebookInstanceLifecycleConfigReference = NotebookInstanceLifecycleConfigReference.builder()
 *         .notebookInstanceLifecycleConfigId("notebookInstanceLifecycleConfigId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.936Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_sagemaker.NotebookInstanceLifecycleConfigReference")
@software.amazon.jsii.Jsii.Proxy(NotebookInstanceLifecycleConfigReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface NotebookInstanceLifecycleConfigReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the NotebookInstanceLifecycleConfig resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNotebookInstanceLifecycleConfigId();

    /**
     * @return a {@link Builder} of {@link NotebookInstanceLifecycleConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NotebookInstanceLifecycleConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<NotebookInstanceLifecycleConfigReference> {
        java.lang.String notebookInstanceLifecycleConfigId;

        /**
         * Sets the value of {@link NotebookInstanceLifecycleConfigReference#getNotebookInstanceLifecycleConfigId}
         * @param notebookInstanceLifecycleConfigId The Id of the NotebookInstanceLifecycleConfig resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notebookInstanceLifecycleConfigId(java.lang.String notebookInstanceLifecycleConfigId) {
            this.notebookInstanceLifecycleConfigId = notebookInstanceLifecycleConfigId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NotebookInstanceLifecycleConfigReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public NotebookInstanceLifecycleConfigReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NotebookInstanceLifecycleConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NotebookInstanceLifecycleConfigReference {
        private final java.lang.String notebookInstanceLifecycleConfigId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.notebookInstanceLifecycleConfigId = software.amazon.jsii.Kernel.get(this, "notebookInstanceLifecycleConfigId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.notebookInstanceLifecycleConfigId = java.util.Objects.requireNonNull(builder.notebookInstanceLifecycleConfigId, "notebookInstanceLifecycleConfigId is required");
        }

        @Override
        public final java.lang.String getNotebookInstanceLifecycleConfigId() {
            return this.notebookInstanceLifecycleConfigId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("notebookInstanceLifecycleConfigId", om.valueToTree(this.getNotebookInstanceLifecycleConfigId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_sagemaker.NotebookInstanceLifecycleConfigReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NotebookInstanceLifecycleConfigReference.Jsii$Proxy that = (NotebookInstanceLifecycleConfigReference.Jsii$Proxy) o;

            return this.notebookInstanceLifecycleConfigId.equals(that.notebookInstanceLifecycleConfigId);
        }

        @Override
        public final int hashCode() {
            int result = this.notebookInstanceLifecycleConfigId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/sagemaker/NotebookInstanceLifecycleConfigReference.java <==
package software.amazon.awscdk.interfaces.sagemaker;

/**
 * A reference to a NotebookInstanceLifecycleConfig resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.sagemaker.*;
 * NotebookInstanceLifecycleConfigReference notebookInstanceLifecycleConfigReference = NotebookInstanceLifecycleConfigReference.builder()
 *         .notebookInstanceLifecycleConfigId("notebookInstanceLifecycleConfigId")
 *         .notebookInstanceLifecycleConfigName("notebookInstanceLifecycleConfigName")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.152Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_sagemaker.NotebookInstanceLifecycleConfigReference")
@software.amazon.jsii.Jsii.Proxy(NotebookInstanceLifecycleConfigReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface NotebookInstanceLifecycleConfigReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the NotebookInstanceLifecycleConfig resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNotebookInstanceLifecycleConfigId();

    /**
     * The NotebookInstanceLifecycleConfigName of the NotebookInstanceLifecycleConfig resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNotebookInstanceLifecycleConfigName();

    /**
     * @return a {@link Builder} of {@link NotebookInstanceLifecycleConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NotebookInstanceLifecycleConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<NotebookInstanceLifecycleConfigReference> {
        java.lang.String notebookInstanceLifecycleConfigId;
        java.lang.String notebookInstanceLifecycleConfigName;

        /**
         * Sets the value of {@link NotebookInstanceLifecycleConfigReference#getNotebookInstanceLifecycleConfigId}
         * @param notebookInstanceLifecycleConfigId The Id of the NotebookInstanceLifecycleConfig resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notebookInstanceLifecycleConfigId(java.lang.String notebookInstanceLifecycleConfigId) {
            this.notebookInstanceLifecycleConfigId = notebookInstanceLifecycleConfigId;
            return this;
        }

        /**
         * Sets the value of {@link NotebookInstanceLifecycleConfigReference#getNotebookInstanceLifecycleConfigName}
         * @param notebookInstanceLifecycleConfigName The NotebookInstanceLifecycleConfigName of the NotebookInstanceLifecycleConfig resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notebookInstanceLifecycleConfigName(java.lang.String notebookInstanceLifecycleConfigName) {
            this.notebookInstanceLifecycleConfigName = notebookInstanceLifecycleConfigName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NotebookInstanceLifecycleConfigReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public NotebookInstanceLifecycleConfigReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NotebookInstanceLifecycleConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NotebookInstanceLifecycleConfigReference {
        private final java.lang.String notebookInstanceLifecycleConfigId;
        private final java.lang.String notebookInstanceLifecycleConfigName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.notebookInstanceLifecycleConfigId = software.amazon.jsii.Kernel.get(this, "notebookInstanceLifecycleConfigId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.notebookInstanceLifecycleConfigName = software.amazon.jsii.Kernel.get(this, "notebookInstanceLifecycleConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.notebookInstanceLifecycleConfigId = java.util.Objects.requireNonNull(builder.notebookInstanceLifecycleConfigId, "notebookInstanceLifecycleConfigId is required");
            this.notebookInstanceLifecycleConfigName = java.util.Objects.requireNonNull(builder.notebookInstanceLifecycleConfigName, "notebookInstanceLifecycleConfigName is required");
        }

        @Override
        public final java.lang.String getNotebookInstanceLifecycleConfigId() {
            return this.notebookInstanceLifecycleConfigId;
        }

        @Override
        public final java.lang.String getNotebookInstanceLifecycleConfigName() {
            return this.notebookInstanceLifecycleConfigName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("notebookInstanceLifecycleConfigId", om.valueToTree(this.getNotebookInstanceLifecycleConfigId()));
            data.set("notebookInstanceLifecycleConfigName", om.valueToTree(this.getNotebookInstanceLifecycleConfigName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_sagemaker.NotebookInstanceLifecycleConfigReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NotebookInstanceLifecycleConfigReference.Jsii$Proxy that = (NotebookInstanceLifecycleConfigReference.Jsii$Proxy) o;

            if (!notebookInstanceLifecycleConfigId.equals(that.notebookInstanceLifecycleConfigId)) return false;
            return this.notebookInstanceLifecycleConfigName.equals(that.notebookInstanceLifecycleConfigName);
        }

        @Override
        public final int hashCode() {
            int result = this.notebookInstanceLifecycleConfigId.hashCode();
            result = 31 * result + (this.notebookInstanceLifecycleConfigName.hashCode());
            return result;
        }
    }
}
